#ifndef W_MOUSEFUN_H
#define W_MOUSEFUN_H
/*
 * FIG : Facility for Interactive Generation of figures
 * Copyright (c) 1991 by Paul King
 *
 * The X Consortium, and any party obtaining a copy of these files from
 * the X Consortium, directly or indirectly, is granted, free of charge, a
 * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
 * nonexclusive right and license to deal in this software and
 * documentation files (the "Software"), including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software subject to the restriction stated
 * below, and to permit persons who receive copies from any such party to
 * do so, with the only requirement being that this copyright notice remain
 * intact.
 * This license includes without limitation a license to do the foregoing
 * actions under any patents of the party supplying this software to the 
 * X Consortium.
 *
 */

void		init_mousefun();
void		setup_mousefun();
void		set_mousefun();
void		draw_mousefun_mode();
void		draw_mousefun_ind();
void		draw_mousefun_unitbox();
void		shift_top_mousfun();
void		draw_mousefun_topruler();
void		shift_side_mousfun();
void		draw_mousefun_sideruler();
void		draw_mousefun_canvas();
void		draw_mousefun();
void		draw_mousefn2();
void		clear_mousefun();
void		notused_middle();
void		clear_middle();
void		notused_right();
void		clear_right();
void		draw_mousefun_kbd();
void		clear_mousefun_kbd();
void		init_mousefun_actions();
extern String	kbd_translations;
#endif /* W_MOUSEFUN_H */
